Module i64

Module i64 

Predicates for i64 values.

Structs

Equal
Checks whether the given value is equal to N.
Greater
Checks whether the given value is greater than N.
GreaterOrEqual
Checks whether the given value is greater than or equal to N.
Less
Checks whether the given value is less than N.
LessOrEqual
Checks whether the given value is less than or equal to N.
Modulo
Checks whether i64 divided by D has modulo M.
NotEqual
Checks whether the given value is not equal to N.

Constants

TWO
Represents two (2).
ZERO
Represents zero (0).

Type Aliases

Closed
Represents [M, N] intervals.
ClosedOpen
Represents [M, N) intervals.
Divisible
Checks whether the given value is divisible by D.
Even
Checks whether the given value is even.
Negative
Checks whether the given value is negative.
NonNegative
Checks whether the given value is non-negative (positive or zero).
NonPositive
Checks whether the given value is non-positive (negative or zero).
NonZero
Checks whether the given value is not equal to zero (0).
Odd
Checks whether the given value is odd.
Open
Represents (M, N) intervals.
OpenClosed
Represents (M, N] intervals.
Positive
Checks whether the given value is positive.
Zero
Checks whether the given value is equal to zero (0).