Module u64

Module u64 

Predicates for u64 values.

Structs

Equal
Checks whether the given value is equal to N.
Greater
Checks whether the given value is greater than N.
GreaterOrEqual
Checks whether the given value is greater than or equal to N.
Less
Checks whether the given value is less than N.
LessOrEqual
Checks whether the given value is less than or equal to N.
Modulo
Checks whether u64 divided by D has modulo M.
NotEqual
Checks whether the given value is not equal to N.

Constants

TWO
Represents two (2).
ZERO
Represents zero (0).

Type Aliases

Closed
Represents [M, N] intervals.
ClosedOpen
Represents [M, N) intervals.
Divisible
Checks whether the given value is divisible by D.
Even
Checks whether the given value is even.
NonZero
Checks whether the given value is not equal to zero (0).
Odd
Checks whether the given value is odd.
Open
Represents (M, N) intervals.
OpenClosed
Represents (M, N] intervals.
Zero
Checks whether the given value is equal to zero (0).